@@ -14,22 +14,22 @@ if sys.version_info >= (3, 0):
     from io import BytesIO as MemoryIO
     xrange = range
 
-
     def py3_btou(n, encoding=_encoding):
         return n.decode(encoding)
 
-
     def py3_utob(n, encoding=_encoding):
         return bytes(n, encoding)
 
-    def json_dump(obj, indent):
+    unicode = str
+    long = int
+
+    def py3_json_dump(obj, indent):
         json.dump(obj, stdout, indent=indent)
 
 else:  # Python 2x
     from cStringIO import StringIO as MemoryIO
     xrange = xrange
 
-
     def py2_btou(n, encoding=_encoding):
         return n
 
@@ -37,14 +37,19 @@ else:  # Python 2x
     def py2_utob(n, encoding=_encoding):
         return n
 
+    unicode = unicode
+    long = long
+
     _outenc = getattr(stdout, 'encoding', _encoding)
-    def json_dump(obj, indent):
+    def py2_json_dump(obj, indent):
         json.dump(obj, stdout, indent=indent, encoding=_outenc)
 
 # We do it this way and not just redifine function since Cython do not like it
 if sys.version_info >= (3, 0):
     btou = py3_btou
     utob = py3_utob
+    json_dump = py3_json_dump
 else:
     btou = py2_btou
     utob = py2_utob
+    json_dump = py2_json_dump
